==> ckeditor_tippy-1.0.4.tar.gz: ckeditor_tippy/src/Plugin/CKEditorPlugin/DrupalImageTippyTooltip.php <==
<?php

namespace Drupal\ckeditor_tippy\Plugin\CKEditorPlugin;

use Drupal\Core\Plugin\PluginBase;
use Drupal\editor\Entity\Editor;
use Drupal\ckeditor\CKEditorPluginInterface;
use Drupal\ckeditor\CKEditorPluginContextualInterface;

/**
 * Defines the "drupalimagetippy" plugin.
 *
 * @CKEditorPlugin(
 *   id = "drupalimagetippy",
 *   label = @Translation("Drupal image tippy tooltip widget"),
 *   module = "ckeditor_tippy"
 * )
 */
class DrupalImageTippyTooltip extends PluginBase implements CKEditorPluginInterface, CKEditorPluginContextualInterface {

  /**
   * {@inheritdoc}
   */
  public function isInternal() {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getLibraries(Editor $editor) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getConfig(Editor $editor) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getDependencies(Editor $editor) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getFile() {
    return drupal_get_path('module', 'ckeditor_tippy') . '/js/plugins/drupalimagetippy/plugin.js';
  }

  /**
   * {@inheritdoc}
   */
  public function isEnabled(Editor $editor) {
    if (!$editor->hasAssociatedFilterFormat()) {
      return FALSE;
    }

    $settings = $editor->getSettings();
    foreach ($settings['toolbar']['rows'] as $row) {
      foreach ($row as $group) {
        foreach ($group['items'] as $button) {
          if ($button === 'DrupalImage') {
            return TRUE;
          }
        }
      }
    }

    return FALSE;
  }

}

==> ckeditor_tippy-1.0.9.tar.gz: ckeditor_tippy/src/Plugin/CKEditorPlugin/DrupalImageTippyTooltip.php <==
<?php

namespace Drupal\ckeditor_tippy\Plugin\CKEditorPlugin;

use Drupal\Core\Plugin\PluginBase;
use Drupal\editor\Entity\Editor;
use Drupal\ckeditor\CKEditorPluginInterface;
use Drupal\ckeditor\CKEditorPluginContextualInterface;

/**
 * Defines the "drupalimagetippy" plugin.
 *
 * @CKEditorPlugin(
 *   id = "drupalimagetippy",
 *   label = @Translation("Drupal image tippy tooltip widget"),
 *   module = "ckeditor_tippy"
 * )
 */
class DrupalImageTippyTooltip extends PluginBase implements CKEditorPluginInterface, CKEditorPluginContextualInterface {

  /**
   * {@inheritdoc}
   */
  public function isInternal() {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getLibraries(Editor $editor) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getConfig(Editor $editor) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getDependencies(Editor $editor) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getFile() {
    return \Drupal::service('extension.list.module')->getPath('ckeditor_tippy') . '/js/plugins/drupalimagetippy/plugin.js';
  }

  /**
   * {@inheritdoc}
   */
  public function isEnabled(Editor $editor) {
    if (!$editor->hasAssociatedFilterFormat()) {
      return FALSE;
    }

    $settings = $editor->getSettings();
    foreach ($settings['toolbar']['rows'] as $row) {
      foreach ($row as $group) {
        foreach ($group['items'] as $button) {
          if ($button === 'DrupalImage') {
            return TRUE;
          }
        }
      }
    }

    return FALSE;
  }

}
